<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;

use App\Post;
use App\Tag;
use App\Image;
use App\User;
use Form;
use \Carbon\Carbon;

use Input;
use Session;
use Validator;

class BackController extends Controller
{

    public function __construct() {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $posts = Post::with('tags')->paginate(10);

        return view('dashboard.posts.index', compact('posts'));
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $tags = Tag::lists('name', 'id');

        return view('dashboard.posts.create', compact('tags'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $post = Post::create($request->all());

        // gestion du checkbox boolean 'en ligne?' :
        $post->status = (empty($request->input('status')))? 0 : 1;


        // envoi des tags a la bdd :
        $post->tags()->sync($request->get('tags'));



        // FILES :
        $file   = array('image' => Input::file('image'));
        $rules  = array('image' => 'required',);

        //if ( !empty($_POST['image']) ) {
            if (Input::file('image')->isValid()) {
                $destinationPath = 'uploads';
                $extension = Input::file('image')->getClientOriginalExtension();
                $fileName = rand(11111, 99999) . '.' . $extension;
                Input::file('image')->move($destinationPath, $fileName);

                // on insere un champ 'name' dans la bdd 'images' :
                $image = Image::create($request->all());
                $image->name = $fileName;
                $image->save();

                // on insere un champ 'id' dans la bdd 'posts' :
                $image_id = $image->id;
                $post->image_id = $image_id;
                $post->save();
            } else {
                return redirect(route('admin.posts.edit', $post))->with('message', 'Erreur : l\'image n\'est pas bonne');
                die();
            }
        //}



        return redirect(route('admin.posts.edit', $post))->with('message', 'Le conférence à bien été créer ! Vous pouvez maitenant l\'éditer');
    }



    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $post = Post::findOrFail($id);
        return view('dashboard.posts.show', compact('post'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $post = Post::findOrFail($id);
        $tags = Tag::lists('name', 'id');

        return view('dashboard.posts.edit', compact('post', 'tags'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $post = Post::findOrFail($id);

        $post->update($request->all());


        // gestion du checkbox boolean 'en ligne?' :
        $post->status = (empty($request->input('status')))? 0 : 1;
        $post->save();

        // envoi des tags a la bdd :
        $post->tags()->sync($request->get('tags'));

/*
        // FILES :
        $file   = array('image' => Input::file('image'));
        $rules  = array('image' => 'required',); //mimes:jpeg,bmp,png and for max size max:10000

        if (Input::file('image')->isValid()) {
            $destinationPath = 'uploads';
            $extension = Input::file('image')->getClientOriginalExtension();
            $fileName = rand(11111,99999).'.'.$extension;
            Input::file('image')->move($destinationPath, $fileName);

            // on insere un champ 'name' dans la bdd 'images' :
            $image = Image::create($request->all());
            $image->name = $fileName;
            $image->save();

            // on insere un champ 'id' dans la bdd 'posts' :
            $image_id = $image->id;
            $post->image_id = $image_id;
            $post->save();
        } else {
            return redirect(route('admin.posts.edit', $post))->with('message', 'Erreur : l\'image n\'est pas bonne');
            die();
        }
*/

        return redirect(route('admin.posts.edit', $id))->with('message', 'Le poste à bien été modifier !');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Post::find($id)->delete();
        return redirect()->to('admin/posts/')->with('message', 'Conférence suprimé !');
    }
}
